# -*- coding: utf-8 -*-
# Copyright (C) 2019 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from . import Gmpv208TestCase
from .testcmds import *  # pylint: disable=wildcard-import


class Gmpv208CloneAgentTestCase(GmpCloneAgentTestCase, Gmpv208TestCase):
    pass


class Gmpv208CreateFilterTestCase(GmpCreateFilterTestCase, Gmpv208TestCase):
    pass


class Gmpv208CreatePermissionTestCase(
    GmpCreatePermissionTestCase, Gmpv208TestCase
):
    pass


class Gmpv208CreateTagTestCase(GmpCreateTagTestCase, Gmpv208TestCase):
    pass


class Gmpv208CreateTargetCommandTestCase(
    GmpCreateTargetCommandTestCase, Gmpv208TestCase
):
    pass


class Gmpv208GetAggregatesTestCase(GmpGetAggregatesTestCase, Gmpv208TestCase):

    pass


class Gmpv208GetInfoTestCase(GmpGetInfoTestCase, Gmpv208TestCase):
    pass


class Gmpv208ModifyFilterTestCase(GmpModifyFilterTestCase, Gmpv208TestCase):
    pass


class Gmpv208ModifyPermissionTestCase(
    GmpModifyPermissionTestCase, Gmpv208TestCase
):
    pass


class Gmpv208ModifyReportFormatTestCase(
    GmpModifyReportFormatTestCase, Gmpv208TestCase
):
    pass


class Gmpv208ModifyTagTestCase(GmpModifyTagTestCase, Gmpv208TestCase):
    pass
